"use client"

import type {ICryptoInWalletInfo} from "@/interfaces/crypto.interface";
import {CryptosTable} from "@/components/data-tables/cryptos-table";
import {useEffect, useState} from "react";
import {Skeleton} from "@/components/ui/skeleton";
import ApiRequest from "@/services/apiRequest";
import type {IApiAllOffersRes} from "@/interfaces/api.interface";


export default function DashboardPage() {
	const [isLoading, setIsLoading] = useState<boolean>(true)
	const [cryptosList, setCryptosList] = useState<ICryptoInWalletInfo[]>([])
	//FIX the loop

	useEffect(() => {
		ApiRequest.authenticated.get.json<ICryptoInWalletInfo[]>(
			"crypto/all"
		).then((response)=>{
			if (response.data.length <= 0) {
				setCryptosList([])
				setIsLoading(false)
				return
			}
			const resp = response.data
			setCryptosList(resp)
			setIsLoading(false)
		})
	}, []);

	if (isLoading) {
		return (<div className={"container flex flex-col justify-center items-center min-h-64 my-6 gap-4"}>
			<h1 className={"text-2xl font-bold"}>Available cryptos</h1>
			<Skeleton className={"container flex flex-col justify-center items-center min-h-64 my-6 gap-4"}/>
		</div>)
	}

	return (<>
		<section className={"container flex flex-col justify-center items-center min-h-64 my-6 gap-4"}>
			<h1 className={"text-2xl font-bold"}>Available cryptos</h1>
			<CryptosTable cryptosArray={cryptosList}/>
		</section>
	</>)
}