'use client'
import * as React from 'react';
import type {ICryptoInWalletInfo} from "@/interfaces/crypto.interface";

import {
 type ColumnDef,
 flexRender,
 getCoreRowModel,
 useReactTable,
} from "@tanstack/react-table"
import {DataTable} from "@/components/ui/data-table";
import {Button} from "@/components/ui/button";
import {ArrowUpDown, MoreHorizontal} from "lucide-react";
import {useRouter} from "next/navigation";
import {useState} from "react";
import {BuyModal} from "@/components/cryptos/buy-modal";
import {ViewModal} from "@/components/cryptos/view-modal";

interface DataTableProps<TData, TValue> {
 columns: ColumnDef<TData, TValue>[]
 data: TData[]
}

type Props = {
	cryptosArray: ICryptoInWalletInfo[]
};

export function CryptosTable(props: Props) {
	const router = useRouter()
	const cryptos= props.cryptosArray

	const columns: ColumnDef<ICryptoInWalletInfo, any>[] = [
		{
			accessorKey: "name",
			header: "Name",
		},
		{
			accessorKey: "value",
			header: ({ column }) => {
				return (
					<Button
						variant="light"
						onClick={() => column.toggleSorting(column.getIsSorted() === "asc")}
					>
						Value - USD
						<ArrowUpDown className="ml-2 h-4 w-4" />
					</Button>
				)
			},
		},
		{
			accessorKey: "quantity",
			header: ({ column }) => {
				return (
					<Button
						variant="light"
						onClick={() => column.toggleSorting(column.getIsSorted() === "asc")}
					>
						Available from server
						<ArrowUpDown className="ml-2 h-4 w-4" />
					</Button>
				)
			},
		},
		{
			id: "actions",
			cell: ({ row }) => {
				const payment = row.original

				return (
					<div className={"flex gap-2"}>
						<BuyModal cryptoData={row.original}/>
						<ViewModal targetedCryptoId={row.original.id}/>
					</div>
				)
			},
		},
	];

	return (
		<>
			<DataTable columns={columns} data={cryptos} fieldToFilter={"name"}/>
		</>
	);

}